This crate contains kube-rs compatible bindings for Kubernetes custom resources for the monocle.monocle.change-metrics.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
monocle.monocle.change-metrics.io/v1alpha1
Monocle